==> tetzle_2.2.2.orig.tar.gz: tetzle-2.2.2/translations/tetzle_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Вигляд</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Скісні краї</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Різкі тіні</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Колір</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Фон:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Тінь:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Підсвічування:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Зображення немає.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Будь ласка, зачекайте</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Завантаження зображення...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Генерування пазлу...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Створення елементів...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Завантаження пазлу...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Невідомий формат даних</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Невідомий елемент &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Помилка аналізу XML-файла.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Завантаження елементів...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Отримання елементів...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Розташування елементів...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успішно</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Вибрати гру</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Поточні ігри</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Нова гра</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Властивості зображення</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Мітки:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Вибрати мову програми:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системна мова&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Нотатка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустіть програму, щоб зміна мови набула сили.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Додати зображення</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Вилучити зображення</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Властивості зображення</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 елементів</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Копіювання зображень...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Вилучити вибране зображення?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Вилучити вибране зображення?

Є збережені ігри з таким зображенням, що також будуть вилучені.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 елементів %2 %3% завершено</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Вилучити гру</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Вилучити вибрану гру?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Огляд</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Додати мітку</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Видалити мітку</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Без мітки</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Всі зображення</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Без назви %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запит</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Вилучити вибрану мітку?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>На жаль</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Мітка з такою назвою вже є.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Отримати елементи</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вийти</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Вибрати...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вигляд</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Збільшити</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Зм&amp;еншити</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Найкращий &amp;добір</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Показати о&amp;гляд</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>На по&amp;вний екран</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Вигляд...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Мова...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Керування</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Пр&amp;о гру</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Про &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Керування</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Підняти елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Ліва кнопка миші або пробіл</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Опустити елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вибрати елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Ліве перетягування</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Обернути елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Права кнопка миші, Ctrl + ліва кнопка або R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Перетягти пазл:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Середня кнопка, Shift + ліва кнопка або стрілки</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Масштабувати пазл:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Колесо миші або +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Перемістити курсор:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Перемістити мишу або W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Про Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Головоломка з тетроміно на шматки</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Випущено за ліцензією &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Оберіть версію OpenGL.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>версія</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Додати зображення до діалогового вікна вибору гри.</translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Вигляд</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Скісні краї</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Різкі тіні</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Колір</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Фон:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Тінь:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Підсвічування:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Зображення немає.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Будь ласка, зачекайте</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Завантаження зображення...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Генерування пазлу...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Створення елементів...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Завантаження пазлу...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Невідомий формат даних</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Невідомий елемент &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Помилка аналізу XML-файла.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Завантаження елементів...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Отримання елементів...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Розташування елементів...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успішно</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Вибрати гру</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Поточні ігри</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Нова гра</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Властивості зображення</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Мітки:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Вибрати мову програми:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системна мова&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Нотатка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустіть програму, щоб зміна мови набула сили.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Додати зображення</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Вилучити зображення</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Властивості зображення</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 елементів</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Копіювання зображень...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 елементів %2 %3% завершено</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Вилучити гру</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Вилучити вибрану гру?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Огляд</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Додати мітку</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Видалити мітку</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Без мітки</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Всі зображення</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Без назви %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запит</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Вилучити вибрану мітку?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>На жаль</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Мітка з такою назвою вже є.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Отримати елементи</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вийти</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Вибрати...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вигляд</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Збільшити</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Зм&amp;еншити</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Найкращий &amp;добір</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Показати о&amp;гляд</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>На по&amp;вний екран</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Вигляд...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Мова...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Керування</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Пр&amp;о гру</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Про &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Керування</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Підняти елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Ліва кнопка миші або пробіл</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Опустити елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вибрати елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Ліве перетягування</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Обернути елементи:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Права кнопка миші, Ctrl + ліва кнопка або R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Перетягти пазл:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Середня кнопка, Shift + ліва кнопка або стрілки</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Масштабувати пазл:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Колесо миші або +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Перемістити курсор:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Перемістити мишу або W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Про Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Головоломка з тетроміно на шматки</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Випущено за ліцензією &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Додати зображення до діалогового вікна вибору гри.</translation>
    </message>
</context>
</TS>
